Received: from maia.hub.org (maia-3.hub.org [200.46.204.243]) by mail.postgresql.org (Postfix) with ESMTP id 246DE1337990 for ; Mon, 8 Nov 2010 02:36:30 -0400 (AST) Received: from mail.postgresql.org ([200.46.204.86]) by maia.hub.org (mx1.hub.org [200.46.204.243]) (amavisd-maia, port 10024) with ESMTP id 52541-08 for ; Mon, 8 Nov 2010 06:36:22 +0000 (UTC) X-Greylist: from auto-whitelisted by SQLgrey-1.7.6 Received: from kuber.nabble.com (kuber.nabble.com [216.139.236.158]) by mail.postgresql.org (Postfix) with ESMTP id A1B99133729E for ; Mon, 8 Nov 2010 02:36:22 -0400 (AST) Received: from sam.nabble.com ([192.168.236.26]) by kuber.nabble.com with esmtp (Exim 4.63) (envelope-from ) id 1PFL2G-0005xs-F6 for pgsql-performance@postgresql.org; Sun, 07 Nov 2010 22:16:56 -0800 Date: Sun, 7 Nov 2010 22:16:56 -0800 (PST) From: "shaiju.ck" To: pgsql-performance@postgresql.org Message-ID: <1289197016462-3254568.post@n5.nabble.com> Subject: Select * is very slow MIME-Version: 1.0 Content-Type: multipart/alternative; boundary="----=_Part_22848_17781059.1289197016461" X-Virus-Scanned: Maia Mailguard 1.0.1 X-Spam-Status: No, hits=-0.777 tagged_above=-10 required=5 tests=BAYES_00=-1.9, HTML_MESSAGE=0.001, URI_HEX=1.122 X-Spam-Level: X-Archive-Number: 201011/100 X-Sequence-Number: 41124 ------=_Part_22848_17781059.1289197016461 Content-Type: text/plain; charset=us-ascii Content-Transfer-Encoding: 7bit Hi, I have a table employee with 33 columns. The table have 200 records now. Select * from employee takes 15 seconds to fetch the data!!! Which seems to be very slow. But when I say select id,name from empoyee it executes in 30ms. Same pefromance if I say select count(*) from emloyee. Why the query is slow if I included all the columns in the table. As per my understanding , number of columns should not be having a major impact on the query performance. I have increased the shared_buffres to 1024MB, but no improvement. I have noticed that the query "show shared_buffers" always show 8MB.Why is this? Does it mean that changing the shared_buffers in config file have no impact? Can anybody help? Shaiju -- View this message in context: http://postgresql.1045698.n5.nabble.com/Select-is-very-slow-tp3254568p3254568.html Sent from the PostgreSQL - performance mailing list archive at Nabble.com. ------=_Part_22848_17781059.1289197016461 Content-Type: text/html; charset=us-ascii Content-Transfer-Encoding: 7bit Hi, I have a table employee with 33 columns. The table have 200 records now. Select * from employee takes 15 seconds to fetch the data!!! Which seems to be very slow. But when I say select id,name from empoyee it executes in 30ms. Same pefromance if I say select count(*) from emloyee. Why the query is slow if I included all the columns in the table. As per my understanding , number of columns should not be having a major impact on the query performance. I have increased the shared_buffres to 1024MB, but no improvement. I have noticed that the query "show shared_buffers" always show 8MB.Why is this? Does it mean that changing the shared_buffers in config file have no impact? Can anybody help? Shaiju

View this message in context: Select * is very slow
Sent from the PostgreSQL - performance mailing list archive at Nabble.com.
------=_Part_22848_17781059.1289197016461--